/*
 * This first version of the ESPLine series JUST receives UDP messages and displays
 * the content on the serial console.
 *
 * This program SHOULD run in an ESP8266 module directly attached to a "mouse" robot.
 * The plan is for it to receive UDP packets that control the speeds of its two wheels.
 *
 * The received packet should contain two three-byte integers in the range of 0-999 with
 * a comma between. The first controls the left wheel's PWM duty cycle and the second
 * controls the right wheel's duty cycle.
 *
 * Any packets with the wrong length OR the comma missing will be completely ignored.
 *
 * written by John de Longpre aka John@deLongpre.com, licensed under GNU GPL v3.0
 * see LICENSE.txt in this folder or visit http://www.gnu.org/
*/

#include <ESP8266WiFi.h>
#include <WiFiUDP.h>

WiFiUDP Udp;

const char* ssid     = "HomeToo";
const char* password = "MyWiFiPass";

#define UDPPORT 4949

void setup() {
    Serial.begin(115200);
    delay(10);

    Serial.println();
    Serial.print("Connecting to ");
    Serial.println(ssid);

    WiFi.begin(ssid, password);

    while(WiFi.status() != WL_CONNECTED) {
      Serial.print(".");
        delay(500);
    }

    Serial.println("\nWiFi connected");
    Serial.print("IP address: ");
    Serial.println(WiFi.localIP());
    delay(50);

    if(Udp.begin(UDPPORT) == 1){
      Serial.println("UDP connected");
      } else {
      Serial.println("UDP NOT connected");
      }
}

#define PKTSZ 30
// Loop, displaying packets received
void loop() {
  int packetSize, l_speed, r_speed;
  char inPac[PKTSZ+1];     // allow room for 0x00 to terminate string
  Serial.println("Starting loop");
  packetSize = Udp.parsePacket();
  if(packetSize > 0 ) {
    Serial.println("");
    Serial.print("Received packet of size ");
    Serial.println(packetSize);

    packetSize = Udp.read(inPac, PKTSZ);
    inPac[packetSize]=0;
    Serial.println(inPac);
    if (packetSize == 7 && inPac[3]==',') {
      l_speed = (inPac[0]-'0')*100 + (inPac[1]-'0')*10 + inPac[2]-'0';
      r_speed = (inPac[4]-'0')*100 + (inPac[5]-'0')*10 + inPac[6]-'0';
      Serial.print("Left speed=");
      Serial.print(l_speed);
      Serial.print("  Right speed=");
      Serial.println(r_speed);
    }
  }
  delay(50);
}
